@@ -124,7 +124,7 @@ def get_destination_project(src_dir, project=None):
         return project
     return _get_applet_spec(src_dir)['project']
 
-def upload_resources(src_dir, project=None):
+def upload_resources(src_dir, project=None, folder='/'):
     """
     :returns: A list (possibly empty) of references to the generated archive(s)
     :rtype: list
@@ -154,7 +154,7 @@ def upload_resources(src_dir, project=None):
                     dxpy.DXProject(dest_project).new_folder(applet_spec['folder'], parents=True)
                 except dxpy.exceptions.DXAPIError:
                     pass # TODO: make this better
-            target_folder = applet_spec['folder'] if 'folder' in applet_spec else '/'
+            target_folder = applet_spec['folder'] if 'folder' in applet_spec else folder
             dx_resource_archive = dxpy.upload_local_file(tar_fh.name, wait_on_close=True,
                                                          project=dest_project, folder=target_folder, hidden=True)
             archive_link = dxpy.dxlink(dx_resource_archive.get_id())
@@ -443,6 +443,17 @@ def create_app(applet_id, applet_name, src_dir, publish=False, set_default=False
     if categories_to_remove:
         dxpy.api.app_remove_categories(app_id, input_params={'categories': list(categories_to_remove)})
 
+    # Set authorizedUsers list appropriately, but only if provided.
+    authorized_users_to_set = app_spec.get("authorizedUsers")
+    if authorized_users_to_set is not None:
+        existing_authorized_users = dxpy.api.app_list_authorized_users(app_id)['authorizedUsers']
+        authorized_users_to_add = set(authorized_users_to_set) - set(existing_authorized_users)
+        authorized_users_to_remove = set(existing_authorized_users) - set(authorized_users_to_set)
+        if authorized_users_to_add:
+            dxpy.api.app_add_authorized_users(app_id, input_params={'authorizedUsers': list(authorized_users_to_add)})
+        if authorized_users_to_remove:
+            dxpy.api.app_remove_authorized_users(app_id, input_params={'authorizedUsers': list(authorized_users_to_remove)})
+
     if publish:
         dxpy.api.app_publish(app_id, input_params={'makeDefault': set_default})
     else:
