@@ -138,8 +138,8 @@ class ResolutionError(DXError):
     def __str__(self):
         return self.msg
 
-data_obj_pattern = re.compile('^(record|table|gtable|applet|file)-[0-9A-Za-z]{24}$')
-hash_pattern = re.compile('^(record|table|gtable|app|applet|job|project|container|file)-[0-9A-Za-z]{24}$')
+data_obj_pattern = re.compile('^(record|table|gtable|applet|file|workflow)-[0-9A-Za-z]{24}$')
+hash_pattern = re.compile('^(record|table|gtable|app|applet|workflow|job|analysis|project|container|file)-[0-9A-Za-z]{24}$')
 nohash_pattern = re.compile('^(user|org|app|team)-')
 
 def is_hashid(string):
